import datetime

from wagtail.admin.filters import WagtailFilterSet
from wagtail.admin.widgets import AdminDateInput

import django_filters

from danse.core.models import Evenement, Festival
from danse.jouer.models import Consigne


class EvenementFilterSet(WagtailFilterSet):
    debut = django_filters.DateFilter(
        label="À partir du",
        lookup_expr='date__gte',
        widget=AdminDateInput,
    )

    class Meta:
        model = Evenement
        fields = ['debut', 'lieu']

    def __init__(self, data=None, *args, **kwargs):
        data = data or {}
        data = data.copy()

        # Définis la date d'aujourd'hui pour la date de début
        if not data.get('debut'):
            data['debut'] = datetime.date.today().isoformat()

        super().__init__(data, *args, **kwargs)


class EvenementAdminFilterSet(EvenementFilterSet):
    class Meta(EvenementFilterSet.Meta):
        fields = ['debut', 'lieu', 'structure']


class FestivalFilterSet(WagtailFilterSet):
    debut = django_filters.DateFilter(
        label="À partir du",
        lookup_expr='gte',
        widget=AdminDateInput,
    )

    class Meta:
        model = Festival
        fields = ['debut']

    def __init__(self, data=None, *args, **kwargs):
        data = data or {}
        data = data.copy()

        # Définis la date d'aujourd'hui pour la date de début
        if not data.get('debut'):
            data['debut'] = datetime.date.today().isoformat()

        super().__init__(data, *args, **kwargs)


class ConsigneFilterSet(WagtailFilterSet):
    class Meta:
        model = Consigne
        fields = ['added_by', 'is_available']
