from wagtail.admin.site_summary import SummaryItem

from danse.core.models import Evenement, Structure


class EvenementsSummaryItem(SummaryItem):
    order = 1
    template_name = 'admin/home/summary_evenements.html'

    def get_context_data(self, parent_context):
        context = super().get_context_data(parent_context)

        total_evenements = 0

        qs = Evenement.objects

        if self.request.user.is_structure_user:
            if self.request.user.structure is not None:
                total_evenements = qs.filter(
                    structure=self.request.user.structure
                ).count()
        else:
            total_evenements = qs.count()

        context['total_evenements'] = total_evenements
        return context

    def is_shown(self):
        return self.request.user.has_perm('core.add_evenement')


class StructuresSummaryItem(SummaryItem):
    order = 2
    template_name = 'admin/home/summary_structures.html'

    def get_context_data(self, parent_context):
        context = super().get_context_data(parent_context)

        if self.request.user.is_structure_user:
            context['user_structure'] = self.request.user.structure
        else:
            context['total_structures'] = Structure.objects.count()

        return context

    def is_shown(self):
        return self.request.user.has_perm('core.add_structure') or (
            self.request.user.is_structure_user
            and self.request.user.structure is not None
        )
