from wagtail.admin.ui.tables import Column, TitleColumn

from danse.core.models import Festival

from ..filters import FestivalFilterSet
from ..panels import festival_panels
from ..permissions import festival_permission_policy
from . import base


class IndexView(base.IndexView):
    add_item_label = "Ajouter un festival"
    filterset_class = FestivalFilterSet
    page_title = "Festivals"
    paginate_by = 20
    search_fields = ('nom',)

    columns = [
        TitleColumn(
            'nom', url_name='admin_festival:edit', label="Nom", sort_key='nom'
        ),
        Column('debut', label="Début", sort_key='debut'),
        Column('fin', label="Fin", sort_key='fin'),
    ]


class CreateView(base.CreateView):
    error_message = "Le festival ne peut être enregistré du fait d'erreurs."
    page_title = "Ajouter un festival"
    success_message = "Festival '{0}' ajouté."


class EditView(base.EditView):
    delete_item_label = "Supprimer le festival"
    error_message = "Le festival ne peut être enregistré du fait d'erreurs."
    success_message = "Festival '{0}' mis à jour."


class DeleteView(base.DeleteView):
    confirmation_message = "Êtes-vous sûr⋅e de vouloir supprimer ce festival ?"
    page_title = "Supprimer le festival"
    success_message = "Festival '{0}' supprimé."


class FestivalViewSet(base.ViewSet):
    icon = 'list-ul'
    model = Festival
    permission_policy = festival_permission_policy

    index_view_class = IndexView
    add_view_class = CreateView
    edit_view_class = EditView
    delete_view_class = DeleteView

    panels = festival_panels


class FestivalChooserViewSet(base.ChooserViewSet):
    icon = FestivalViewSet.icon
    model = Festival
    permission_policy = festival_permission_policy

    order_by = 'nom'
    page_title = "Choisir un festival"
    per_page = 10
    search_fields = ('nom',)
