from wagtail.admin.ui.tables import Column, TitleColumn

from danse.core.models import Lieu

from ..panels import lieu_panels
from ..permissions import lieu_permission_policy
from . import base


class IndexView(base.IndexView):
    add_item_label = "Ajouter un lieu"
    page_title = "Lieux"
    paginate_by = 20
    search_fields = ('nom',)

    columns = [
        TitleColumn(
            'nom', url_name='admin_lieu:edit', label="Nom", sort_key='nom'
        ),
        Column('ville', label="Ville"),
    ]

    def get_queryset(self):
        return super().get_queryset().select_related('ville')


class CreateView(base.CreateView):
    error_message = "Le lieu ne peut être enregistré du fait d'erreurs."
    page_title = "Ajouter un lieu"
    success_message = "Lieu '{0}' ajouté."


class EditView(base.EditView):
    delete_item_label = "Supprimer le lieu"
    error_message = "Le lieu ne peut être enregistré du fait d'erreurs."
    success_message = "Lieu '{0}' mis à jour."


class DeleteView(base.DeleteView):
    confirmation_message = "Êtes-vous sûr⋅e de vouloir supprimer ce lieu ?"
    page_title = "Supprimer le lieu"
    success_message = "Lieu '{0}' supprimé."


class LieuViewSet(base.ViewSet):
    icon = 'map-marker'
    model = Lieu
    permission_policy = lieu_permission_policy

    index_view_class = IndexView
    add_view_class = CreateView
    edit_view_class = EditView
    delete_view_class = DeleteView

    panels = lieu_panels


class LieuChooserViewSet(base.ChooserViewSet):
    icon = LieuViewSet.icon
    model = Lieu
    permission_policy = lieu_permission_policy

    order_by = 'nom'
    page_title = "Choisir un lieu"
    per_page = 10
    search_fields = ('nom',)
