from functools import partial

from wagtail.admin.ui.tables import Column, TitleColumn

from danse.core.models import Structure

from ..panels import structure_panels
from ..permissions import structure_permission_policy
from . import base


class IndexView(base.IndexView):
    add_item_label = "Ajouter une structure"
    page_title = "Structures"
    paginate_by = 20
    search_fields = ('nom',)

    columns = [
        TitleColumn(
            'nom', url_name='admin_structure:edit', label="Nom", sort_key='nom'
        ),
        Column('lieu', label="Lieu"),
    ]

    def get_queryset(self):
        return super().get_queryset().select_related('lieu')


class CreateView(base.CreateView):
    error_message = "La structure ne peut être enregistrée du fait d'erreurs."
    page_title = "Ajouter une structure"
    success_message = "Structure '{0}' ajoutée."

    def form_valid(self, form):
        if self.request.user.is_structure_user:
            form._original_save_m2m = form._save_m2m
            form._structure_user = self.request.user

            def save_m2m(self):
                self._original_save_m2m()
                # associe la structure créée au compte
                self._structure_user.structure = self.instance
                self._structure_user.save()

            form._save_m2m = partial(save_m2m, form)
        return super().form_valid(form)


class EditView(base.PermissionInstanceCheckedMixin, base.EditView):
    delete_item_label = "Supprimer la structure"
    error_message = "La structure ne peut être enregistrée du fait d'erreurs."
    success_message = "Structure '{0}' mise à jour."


class DeleteView(base.PermissionInstanceCheckedMixin, base.DeleteView):
    confirmation_message = (
        "Êtes-vous sûr⋅e de vouloir supprimer cette structure ?"
    )
    page_title = "Supprimer la structure"
    success_message = "Structure '{0}' supprimée."


class StructureViewSet(base.ViewSet):
    icon = 'institution'
    model = Structure
    permission_policy = structure_permission_policy

    index_view_class = IndexView
    add_view_class = CreateView
    edit_view_class = EditView
    delete_view_class = DeleteView

    panels = structure_panels


class StructureChooserViewSet(base.ChooserViewSet):
    icon = StructureViewSet.icon
    model = Structure
    permission_policy = structure_permission_policy

    order_by = 'nom'
    page_title = "Choisir un lieu"
    per_page = 10
    search_fields = ('nom',)
