from django.core.exceptions import NON_FIELD_ERRORS

from wagtail.admin.edit_handlers import ObjectList
from wagtail.admin.ui.tables import Column, TitleColumn

from danse.core.models import Ville

from ..forms import VilleForm
from ..panels import ville_panels
from ..permissions import ville_permission_policy
from . import base


class IndexView(base.IndexView):
    add_item_label = "Ajouter une ville"
    page_title = "Villes"
    paginate_by = 20
    search_fields = ('nom',)

    columns = [
        TitleColumn(
            'nom', url_name='admin_ville:edit', label="Nom", sort_key='nom'
        ),
        Column('code_postal', label="Code postal"),
    ]


class VilleFormMixin:
    error_message = "La ville ne peut être enregistrée du fait d'erreurs."

    def get_error_message(self):
        if self.form.is_fetching and set(self.form.errors.keys()) == {
            NON_FIELD_ERRORS
        }:
            return None
        return self.error_message


class CreateView(VilleFormMixin, base.CreateView):
    page_title = "Ajouter une ville"
    success_message = "Ville '{0}' ajoutée."
    template_name = 'admin/ville/create.html'


class EditView(VilleFormMixin, base.EditView):
    delete_item_label = "Supprimer la ville"
    success_message = "Ville '{0}' mise à jour."
    template_name = 'admin/ville/edit.html'


class DeleteView(base.DeleteView):
    confirmation_message = "Êtes-vous sûr⋅e de vouloir supprimer cette ville ?"
    page_title = "Supprimer la ville"
    success_message = "Ville '{0}' supprimée."


class VilleViewSet(base.ViewSet):
    icon = 'city-hall'
    model = Ville
    permission_policy = ville_permission_policy

    index_view_class = IndexView
    add_view_class = CreateView
    edit_view_class = EditView
    delete_view_class = DeleteView

    edit_handler = ObjectList(ville_panels, base_form_class=VilleForm)


class VilleChooserViewSet(base.ChooserViewSet):
    icon = VilleViewSet.icon
    model = Ville
    permission_policy = ville_permission_policy

    order_by = 'nom'
    page_title = "Choisir une ville"
    per_page = 10
    search_fields = ('nom',)
