from django.contrib.auth.models import Permission
from django.urls import reverse

from wagtail.admin.menu import SubmenuMenuItem
from wagtail.core import hooks

from .menu import ModelMenuItem, evenements_menu, jouer_menu, territoire_menu
from .site_summary import EvenementsSummaryItem, StructuresSummaryItem
from .views.consigne import ConsigneViewSet
from .views.evenement import EvenementViewSet
from .views.festival import FestivalChooserViewSet, FestivalViewSet
from .views.lieu import LieuChooserViewSet, LieuViewSet
from .views.structure import StructureChooserViewSet, StructureViewSet
from .views.ville import VilleChooserViewSet, VilleViewSet


@hooks.register('construct_homepage_summary_items')
def add_summary_items(request, items):
    items.append(EvenementsSummaryItem(request))
    items.append(StructuresSummaryItem(request))


@hooks.register('register_admin_viewset')
def register_evenement_viewset():
    return EvenementViewSet('admin_evenement', url_prefix='evenements')


@hooks.register('register_admin_viewset')
def register_festival_viewset():
    return FestivalViewSet('admin_festival', url_prefix='festivals')


@hooks.register('register_admin_viewset')
def register_festival_chooser_viewset():
    return FestivalChooserViewSet(
        'festival_chooser', url_prefix='festivals/chooser'
    )


@hooks.register('register_admin_viewset')
def register_lieu_viewset():
    return LieuViewSet('admin_lieu', url_prefix='lieux')


@hooks.register('register_admin_viewset')
def register_lieu_chooser_viewset():
    return LieuChooserViewSet('lieu_chooser', url_prefix='lieux/chooser')


@hooks.register('register_admin_viewset')
def register_structure_viewset():
    return StructureViewSet('admin_structure', url_prefix='structures')


@hooks.register('register_admin_viewset')
def register_structure_chooser_viewset():
    return StructureChooserViewSet(
        'structure_chooser', url_prefix='structures/chooser'
    )


@hooks.register('register_admin_viewset')
def register_ville_viewset():
    return VilleViewSet('admin_ville', url_prefix='villes')


@hooks.register('register_admin_viewset')
def register_ville_chooser_viewset():
    return VilleChooserViewSet('ville_chooser', url_prefix='villes/chooser')


@hooks.register('register_admin_viewset')
def register_consigne_viewset():
    return ConsigneViewSet('admin_consigne', url_prefix='consignes')


@hooks.register('register_admin_menu_item')
def register_territoire_menu():
    return SubmenuMenuItem(
        "Territoire",
        territoire_menu,
        icon_name='site',
        order=410,
    )


@hooks.register('register_territoire_menu_item')
def register_structure_menu_item():
    return ModelMenuItem(
        StructureViewSet.model,
        StructureViewSet.permission_policy,
        reverse('admin_structure:index'),
        icon_name=StructureViewSet.icon,
        order=10,
    )


@hooks.register('register_territoire_menu_item')
def register_lieu_menu_item():
    return ModelMenuItem(
        LieuViewSet.model,
        LieuViewSet.permission_policy,
        reverse('admin_lieu:index'),
        icon_name=LieuViewSet.icon,
        order=20,
    )


@hooks.register('register_territoire_menu_item')
def register_ville_menu_item():
    return ModelMenuItem(
        VilleViewSet.model,
        VilleViewSet.permission_policy,
        reverse('admin_ville:index'),
        icon_name=VilleViewSet.icon,
        order=30,
    )


@hooks.register('register_admin_menu_item')
def register_evenements_menu():
    return SubmenuMenuItem(
        "Évènements",
        evenements_menu,
        icon_name='date',
        order=420,
    )


@hooks.register('register_evenements_menu_item')
def register_evenement_menu_item():
    return ModelMenuItem(
        EvenementViewSet.model,
        EvenementViewSet.permission_policy,
        reverse('admin_evenement:index'),
        icon_name=EvenementViewSet.icon,
        order=10,
    )


@hooks.register('register_evenements_menu_item')
def register_festival_menu_item():
    return ModelMenuItem(
        FestivalViewSet.model,
        FestivalViewSet.permission_policy,
        reverse('admin_festival:index'),
        icon_name=FestivalViewSet.icon,
        order=20,
    )


@hooks.register('register_admin_menu_item')
def register_jouer_menu():
    return SubmenuMenuItem(
        "Jouer",
        jouer_menu,
        icon_name='puzzle-piece',
        order=430,
    )


@hooks.register('register_jouer_menu_item')
def register_consigne_menu_item():
    return ModelMenuItem(
        ConsigneViewSet.model,
        ConsigneViewSet.permission_policy,
        reverse('admin_consigne:index'),
        icon_name=ConsigneViewSet.icon,
        order=10,
    )


@hooks.register('register_permissions')
def register_permissions():
    return Permission.objects.filter(
        codename__in=[
            'add_evenement',
            'change_evenement',
            'delete_evenement',
            'add_festival',
            'change_festival',
            'delete_festival',
            'add_lieu',
            'change_lieu',
            'delete_lieu',
            'add_structure',
            'change_structure',
            'delete_structure',
            'add_ville',
            'change_ville',
            'delete_ville',
            'add_consigne',
            'change_consigne',
            'delete_consigne',
        ],
    )


@hooks.register('register_icons')
def register_icons(icons):
    for icon in [
        'city-hall',
        'institution',
        'map-marker',
        'save',
        'puzzle-piece',
    ]:
        icons.append('admin/icons/{}.svg'.format(icon))
    return icons
