import pytest
from factory.faker import Faker
from faker import config as faker_config

from danse.notifications.tests.factories import PushSubscriptionFactory
from danse.users.tests.factories import (
    GroupFactory,
    StructureUserFactory,
    UserFactory,
)
from danse.utils.tests.factories import (
    CodePostalProvider,
    DjangoGeoPointProvider,
)

Faker._DEFAULT_LOCALE = 'fr_FR'
Faker.add_provider(CodePostalProvider)
Faker.add_provider(DjangoGeoPointProvider)

faker_config.DEFAULT_LOCALE = 'fr_FR'


@pytest.fixture(autouse=True)
def enable_db_access_for_all_tests(db):
    pass


@pytest.fixture
def faker(faker):
    faker.add_provider(CodePostalProvider)
    faker.add_provider(DjangoGeoPointProvider)
    return faker


# FIXTURES
# ------------------------------------------------------------------------------

USER_PERMISSIONS = ['access_admin']
STRUCTURE_PERMISSIONS = ['access_admin', 'add_evenement', 'add_consigne'] + [
    'view_{}'.format(m)
    for m in {'ville', 'lieu', 'structure', 'evenement', 'consigne'}
]


@pytest.fixture
def user_group():
    return GroupFactory(
        name='Utilisateurs', permissions__codenames=USER_PERMISSIONS
    )


@pytest.fixture
def structure_group():
    return GroupFactory(
        name='Structures', permissions__codenames=STRUCTURE_PERMISSIONS
    )


@pytest.fixture
def user(user_group):
    user = UserFactory()
    user.groups.add(user_group)
    return user


@pytest.fixture
def structure_user(structure_group):
    structure_user = StructureUserFactory()
    structure_user.groups.add(structure_group)
    return structure_user


@pytest.fixture
def subscription():
    return PushSubscriptionFactory(endpoint='https://example.com')
