import datetime

from django_filters import rest_framework as filters

from .. import models


class EvenementFilter(filters.FilterSet):
    debut = filters.DateFilter(lookup_expr='date')
    debut__gte = filters.DateFilter(field_name='debut', lookup_expr='date__gte')
    debut__lte = filters.DateFilter(field_name='debut', lookup_expr='date__lte')
    ville = filters.NumberFilter(field_name='lieu__ville')

    DEBUT_FILTERS = {'debut', 'debut__gte', 'debut__lte'}
    FILTERS_WHITHOUT_INITIAL = DEBUT_FILTERS | {'search'}

    class Meta:
        model = models.Evenement
        fields = [
            'nom',
            'genre',
            'artiste',
            'structure',
            'lieu',
            'debut',
            'festival',
        ]

    def __init__(self, data=None, *args, **kwargs):
        # définis un filtre initial sur la date de début à aujourd'hui
        if data is not None and not set(data.keys()).intersection(
            self.FILTERS_WHITHOUT_INITIAL
        ):
            data = data.copy()
            data['debut__gte'] = datetime.date.today().isoformat()
        super().__init__(data, *args, **kwargs)
