from django.urls import reverse

from wagtail.api.v2.serializers import BaseSerializer
from wagtail.api.v2.utils import get_full_url

from rest_framework import serializers

from danse.utils.api.serializers import StdImageField


class VilleSerializer(BaseSerializer):
    visuel = StdImageField()


class LieuSerializer(BaseSerializer):
    structure_id = serializers.PrimaryKeyRelatedField(
        source='structure', read_only=True
    )


class StructureSerializer(BaseSerializer):
    visuel = StdImageField()
    telephone = serializers.SerializerMethodField()

    def get_telephone(self, obj):
        if not obj.telephone:
            return None
        return {
            key: getattr(obj.telephone, 'as_{}'.format(key))
            for key in ('national', 'rfc3966')
        }


class FestivalSerializer(BaseSerializer):
    visuel = StdImageField()


class EvenementSerializer(BaseSerializer):
    visuel = StdImageField()
    duree = serializers.SerializerMethodField()

    ical_url = serializers.SerializerMethodField()

    def get_duree(self, obj):
        if not obj.duree:
            return None
        return int(obj.duree.total_seconds())

    def get_ical_url(self, obj):
        return get_full_url(
            self.context['request'],
            reverse('api:evenements:detail_ical', args=(obj.id,)),
        )
