# Generated by Django 3.1.3 on 2020-11-17 15:40

import danse.core.models.territoire
import django.contrib.gis.db.models.fields
import django.core.validators
from django.db import migrations, models
import django.db.models.deletion
import dynamic_filenames
import phonenumber_field.modelfields
import re
import stdimage.models
import stdimage.validators
import wagtail.core.fields
import wagtail.search.index


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('wagtailcore', '0059_apply_collection_ordering'),
    ]

    operations = [
        migrations.CreateModel(
            name='Evenement',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('nom', models.CharField(max_length=60, verbose_name='nom')),
                ('genre', models.CharField(choices=[('spectacle', 'Spectacle'), ('atelier', 'Atelier')], max_length=10, verbose_name='genre')),
                ('artiste', models.CharField(max_length=100, verbose_name='artiste')),
                ('description', wagtail.core.fields.RichTextField(verbose_name='description')),
                ('visuel', stdimage.models.StdImageField(help_text="L'image doit être au format JPEG ou PNG avec une taille minimale de 1344x604.", upload_to=dynamic_filenames.FilePattern(filename_pattern='evenements/visuel/{uuid:x}{ext}'), validators=[django.core.validators.FileExtensionValidator(allowed_extensions=('jpg', 'jpeg', 'png')), stdimage.validators.MinSizeValidator(1344, 604)], verbose_name='visuel')),
                ('url_externe', models.URLField(blank=True, verbose_name='lien externe')),
                ('debut', models.DateTimeField(verbose_name='début')),
                ('duree', models.DurationField(blank=True, null=True, verbose_name='durée')),
                ('age_min', models.PositiveSmallIntegerField(blank=True, help_text="Laissez vide si l'évènement est pour tout public.", null=True, verbose_name='âge minimum')),
                ('tarif_plein', models.DecimalField(blank=True, decimal_places=2, help_text="Laissez vide si l'évènement est gratuit.", max_digits=5, null=True, verbose_name='tarif plein')),
                ('tarif_reduit', models.DecimalField(blank=True, decimal_places=2, help_text="Saisissez le plus petit tarif réduit s'il y en a plusieurs de disponibles.", max_digits=5, null=True, verbose_name='tarif réduit')),
                ('url_billetterie', models.URLField(blank=True, verbose_name='lien vers la billetterie')),
                ('date_created', models.DateTimeField(auto_now_add=True)),
                ('date_updated', models.DateTimeField(auto_now=True)),
            ],
            options={
                'verbose_name': 'évènement',
                'verbose_name_plural': 'évènements',
                'ordering': ('debut', 'nom'),
            },
            bases=(wagtail.search.index.Indexed, models.Model),
        ),
        migrations.CreateModel(
            name='Festival',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('nom', models.CharField(max_length=60, verbose_name='nom')),
                ('description', wagtail.core.fields.RichTextField(verbose_name='description')),
                ('visuel', stdimage.models.StdImageField(help_text="L'image doit être au format JPEG ou PNG avec une taille minimale de 1344x604.", upload_to=dynamic_filenames.FilePattern(filename_pattern='festivals/visuel/{uuid:x}{ext}'), validators=[django.core.validators.FileExtensionValidator(allowed_extensions=('jpg', 'jpeg', 'png')), stdimage.validators.MinSizeValidator(1344, 604)], verbose_name='visuel')),
                ('url_externe', models.URLField(blank=True, verbose_name='lien externe')),
                ('debut', models.DateField(verbose_name='début')),
                ('fin', models.DateField(verbose_name='fin')),
            ],
            options={
                'verbose_name': 'festival',
                'verbose_name_plural': 'festivals',
                'ordering': ('debut', 'nom'),
            },
        ),
        migrations.CreateModel(
            name='Lieu',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('nom', models.CharField(max_length=60, verbose_name='nom')),
                ('rue', models.CharField(max_length=100, verbose_name='rue')),
                ('geom', django.contrib.gis.db.models.fields.PointField(null=True, srid=4326, verbose_name='géolocalisation')),
            ],
            options={
                'verbose_name': 'lieu',
                'verbose_name_plural': 'lieux',
                'ordering': ('nom',),
            },
            bases=(danse.core.models.territoire.GeomMixin, wagtail.search.index.Indexed, models.Model),
        ),
        migrations.CreateModel(
            name='StandardPage',
            fields=[
                ('page_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='wagtailcore.page')),
                ('body', wagtail.core.fields.RichTextField(verbose_name='contenu')),
            ],
            options={
                'verbose_name': 'page standard',
                'verbose_name_plural': 'pages standards',
            },
            bases=('wagtailcore.page',),
        ),
        migrations.CreateModel(
            name='Structure',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('nom', models.CharField(max_length=60, unique=True, verbose_name='nom')),
                ('accroche', models.CharField(help_text="Une courte description ou une phrase d'accroche qui apparaîtra en dessous du nom.", max_length=80, verbose_name='accroche')),
                ('description', wagtail.core.fields.RichTextField(verbose_name='description')),
                ('visuel', stdimage.models.StdImageField(help_text="L'image doit être au format JPEG ou PNG avec une taille minimale de 1344x604.", upload_to=dynamic_filenames.FilePattern(filename_pattern='structures/visuel/{uuid:x}{ext}'), validators=[django.core.validators.FileExtensionValidator(allowed_extensions=('jpg', 'jpeg', 'png')), stdimage.validators.MinSizeValidator(1344, 604)], verbose_name='visuel')),
                ('email', models.EmailField(blank=True, max_length=254, verbose_name='adresse courriel')),
                ('telephone', phonenumber_field.modelfields.PhoneNumberField(blank=True, max_length=128, region=None, verbose_name='téléphone')),
                ('url_site', models.URLField(blank=True, verbose_name='lien du site')),
                ('url_billetterie', models.URLField(blank=True, verbose_name='lien vers la billetterie')),
            ],
            options={
                'verbose_name': 'structure',
                'verbose_name_plural': 'structures',
                'ordering': ('nom',),
            },
            bases=(wagtail.search.index.Indexed, models.Model),
        ),
        migrations.CreateModel(
            name='Ville',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('nom', models.CharField(max_length=100, verbose_name='ville')),
                ('code_postal', models.CharField(max_length=5, validators=[django.core.validators.RegexValidator('\\d{5}')], verbose_name='code postal')),
                ('geom', django.contrib.gis.db.models.fields.PointField(null=True, srid=4326, verbose_name='géolocalisation')),
                ('description', wagtail.core.fields.RichTextField(verbose_name='description')),
                ('visuel', stdimage.models.StdImageField(help_text="L'image doit être au format JPEG ou PNG avec une taille minimale de 1344x604.", upload_to=dynamic_filenames.FilePattern(filename_pattern='villes/visuel/{uuid:x}{ext}'), validators=[django.core.validators.FileExtensionValidator(allowed_extensions=('jpg', 'jpeg', 'png')), stdimage.validators.MinSizeValidator(1344, 604)], verbose_name='visuel')),
                ('url_wikipedia', models.URLField(blank=True, validators=[django.core.validators.RegexValidator(re.compile("https://(?P<lang>[\\w]+)\\.wikipedia.org/wiki/(?P<title>[\\w\\-\\'\\%\\(\\)]+)"), code='invalid', message="Entrez une URL d'une page Wikipedia valide.")], verbose_name='lien vers Wikipedia')),
            ],
            options={
                'verbose_name': 'ville',
                'verbose_name_plural': 'villes',
                'ordering': ('nom',),
            },
            bases=(danse.core.models.territoire.GeomMixin, wagtail.search.index.Indexed, models.Model),
        ),
        migrations.AddConstraint(
            model_name='ville',
            constraint=models.UniqueConstraint(fields=('nom', 'code_postal'), name='unique_ville'),
        ),
        migrations.AddField(
            model_name='structure',
            name='lieu',
            field=models.OneToOneField(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='structure', to='core.lieu', verbose_name='lieu'),
        ),
        migrations.AddField(
            model_name='lieu',
            name='ville',
            field=models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, related_name='lieux', to='core.ville', verbose_name='ville'),
        ),
        migrations.AddField(
            model_name='evenement',
            name='festival',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='evenements', to='core.festival', verbose_name='festival'),
        ),
        migrations.AddField(
            model_name='evenement',
            name='lieu',
            field=models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, related_name='evenements', to='core.lieu', verbose_name='lieu'),
        ),
        migrations.AddField(
            model_name='evenement',
            name='structure',
            field=models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, related_name='evenements', to='core.structure', verbose_name='structure'),
        ),
        migrations.AddConstraint(
            model_name='lieu',
            constraint=models.UniqueConstraint(fields=('nom', 'ville'), name='unique_lieu'),
        ),
    ]
