from wagtail.admin.edit_handlers import FieldPanel
from wagtail.api import APIField
from wagtail.core.fields import RichTextField
from wagtail.core.models import Page
from wagtail.core.rich_text import expand_db_html

from rest_framework import serializers


class RichTextSerializer(serializers.Field):
    def to_representation(self, value):
        """
        Étend les représentations de la base de données en code HTML pour
        l'application, comme les liens vers les pages.
        """
        return expand_db_html(value)


class StandardPage(Page):
    """
    Une page de contenu générique. Elle est utilisée pour la page « À
    propos », ainsi que toutes celles qui n'ont besoin que d'un bloc de
    contenu enrichi.
    """

    class Meta:
        verbose_name = "page standard"
        verbose_name_plural = "pages standards"

    # Champs

    body = RichTextField(
        features=['h2', 'h3', 'bold', 'italic', 'ol', 'ul', 'link'],
        verbose_name="contenu",
    )

    # Utilisation des champs

    api_fields = [APIField('body', serializer=RichTextSerializer())]

    # Administration de Wagtail

    content_panels = Page.content_panels + [FieldPanel('body')]

    subpage_types = []
