from django.contrib.gis.geos import Point

import pytest

from .factories import (
    EvenementFactory,
    FestivalFactory,
    LieuFactory,
    StructureFactory,
    VilleFactory,
)


@pytest.fixture
def libreville():
    return VilleFactory(
        nom="Libreville",
        code_postal="01234",
        geom=Point(x=2.8, y=50.68, srid=4326),
        url_wikipedia="https://fr.wikipedia.org/wiki/Libreville",
    )


@pytest.fixture
def olieux(libreville):
    return LieuFactory(
        nom="Olieux",
        rue="13 rue des marguerites",
        ville=libreville,
        geom=Point(x=2.9, y=50.68, srid=4326),
    )


@pytest.fixture
def destructure(olieux):
    return StructureFactory(
        nom="Déstructure",
        accroche="Une scène de la région",
        description="<p>Une description de <b>Déstructure</b>.</p>",
        email="contact@destructure.fr",
        telephone="0987654321",
        url_site="https://destructure.fr",
        url_billetterie="https://destructure.fr/billetterie/",
        lieu=olieux,
    )


@pytest.fixture
def festoch():
    return FestivalFactory(
        nom="Festoch'",
        description="<p>Une description du <b>Festoch'</b> !</p>",
        url_externe="https://festoch.org",
        debut_str='2020-01-17',
        fin_str='2020-01-19',
    )


@pytest.fixture
def evedanse(destructure):
    return EvenementFactory(
        nom="ÈveDanse",
        artiste="Ève - Cie Vivante",
        description="<p>Une description de <b>ÈveDanse</b> !</p>",
        url_externe="https://olieux.fr/evedanse/",
        structure=destructure,
        lieu=destructure.lieu,
        debut_str='2020-01-18 18:00',
        duree_str='1:30:00',
        tarif_plein=10,
        tarif_reduit=3,
        url_billetterie="https://olieux.fr/billeterie/",
        festival=None,
    )
