from django.utils.dateparse import parse_date, parse_datetime, parse_duration
from django.utils.timezone import make_aware

import factory
import wagtail_factories
from factory.django import DjangoModelFactory
from factory.faker import Faker

from .. import models


class VilleFactory(DjangoModelFactory):
    class Meta:
        model = models.Ville

    nom = Faker('city')
    code_postal = Faker('postcode')
    geom = Faker('geo_point')
    description = "<p>Une description de la ville.</p>"
    visuel = factory.django.ImageField(width=1350)


class LieuFactory(DjangoModelFactory):
    class Meta:
        model = models.Lieu

    nom = factory.Sequence(lambda n: "Lieu #%d" % n)
    rue = Faker('street_address')
    ville = factory.SubFactory(VilleFactory)
    geom = Faker('geo_point')


class StructureFactory(DjangoModelFactory):
    class Meta:
        model = models.Structure

    nom = factory.Sequence(lambda n: "Structure #%d" % n)
    accroche = "Une scène de la région"
    description = "<p>Une description de la structure.</p>"
    visuel = factory.django.ImageField(width=1350)
    lieu = factory.SubFactory(LieuFactory)


class FestivalFactory(DjangoModelFactory):
    class Meta:
        model = models.Festival

    class Params:
        debut_str = '2020-01-17'
        fin_str = '2020-01-19'

    nom = factory.Sequence(lambda n: "Festival #%d" % n)
    description = "<p>Une description du festival.</p>"
    visuel = factory.django.ImageField(width=1350)

    debut = factory.LazyAttribute(lambda o: parse_date(o.debut_str))
    fin = factory.LazyAttribute(lambda o: parse_date(o.fin_str))


class EvenementFactory(DjangoModelFactory):
    class Meta:
        model = models.Evenement

    class Params:
        debut_str = '2020-01-17 18:00'
        duree_str = '2:00:00'

    nom = factory.Sequence(lambda n: "Évènement #%d" % n)
    genre = models.Evenement.Genre.SPECTACLE
    artiste = Faker('name')
    description = "<p>Une description de l'évènement.</p>"
    visuel = factory.django.ImageField(width=1350)

    structure = factory.SubFactory(StructureFactory)
    lieu = factory.SelfAttribute('structure.lieu')

    debut = factory.LazyAttribute(
        lambda o: make_aware(parse_datetime(o.debut_str))
    )
    duree = factory.LazyAttribute(lambda o: parse_duration(o.duree_str) or None)


class StandardPageFactory(wagtail_factories.PageFactory):
    class Meta:
        model = models.StandardPage

    title = factory.Sequence(lambda n: "Page #%d" % n)
    body = "<p>Le contenu enrichi de la page.</p>"
