from django.core.management.base import BaseCommand, CommandError

from danse.jouer.models import Consigne, JeuSettings


class Command(BaseCommand):
    help = "Change la consigne du jeu aléatoirement"

    def add_arguments(self, parser):
        parser.add_argument('site_id', type=int)

    def handle(self, *args, **options):
        site_id = options['site_id']
        verbosity = options['verbosity']

        try:
            jeu_settings = JeuSettings.objects.get(site=site_id)
        except JeuSettings.DoesNotExist:
            raise CommandError(
                "Les paramètres du jeu pour ce site n'existent pas."
            )

        try:
            jeu_settings.change_consigne()
        except Consigne.DoesNotExist:
            raise CommandError("Aucune consigne n'est disponible pour le jeu.")

        if verbosity >= 2:
            self.stdout.write(
                "La consigne du jeu est désormais : {}".format(
                    jeu_settings.consigne.consigne
                )
            )
