from django.urls import reverse

from ..models import JeuSettings
from .factories import ConsigneFactory


class TestJouerAPIViewSet:
    consigne_url = reverse('api:jouer:consigne')

    def test_consigne_disabled(self, client):
        response = client.get(self.consigne_url)
        assert response.status_code == 404
        assert response.json() == {
            'detail': (
                "Il n'est pas possible de jouer pour le moement, revenez "
                "plus tard !"
            )
        }

    def test_consigne(self, client):
        consigne = ConsigneFactory(consigne="Une consigne à faire.")

        # on initialise les paramètres
        client.get(self.consigne_url)
        # ... et on active le jeu avec une consigne
        jeu_settings = JeuSettings.objects.first()
        jeu_settings.is_active = True
        jeu_settings.consigne = consigne
        jeu_settings.instructions = "<p>Des instructions pour jouer.</p>"
        jeu_settings.save()

        response = client.get(self.consigne_url)
        assert response.status_code == 200
        assert response.json() == {
            'consigne': "Une consigne à faire.",
            'consigne_id': consigne.id,
            'instructions': "<p>Des instructions pour jouer.</p>",
        }
