from io import StringIO

from django.core.management import call_command
from django.core.management.base import CommandError

from wagtail.core.models import Site

import pytest

from ..models import JeuSettings
from .factories import ConsigneFactory


@pytest.fixture
def jeu_settings():
    return JeuSettings.for_site(Site.objects.get(is_default_site=True))


class TestChangeConsigne:
    def test_site_unkown(self):
        with pytest.raises(CommandError) as excinfo:
            call_command('changeconsigne', 10)
        assert "ce site n'existent pas" in str(excinfo)

    def test_no_consigne(self, jeu_settings):
        with pytest.raises(CommandError) as excinfo:
            call_command('changeconsigne', jeu_settings.site_id)
        assert "Aucune consigne" in str(excinfo)

    def test_quiet(self, jeu_settings):
        consigne = ConsigneFactory()

        out = StringIO()
        call_command('changeconsigne', 1, stdout=out)
        assert not out.getvalue()
        jeu_settings.refresh_from_db()
        assert jeu_settings.consigne == consigne

    def test_verbose(self, jeu_settings):
        consigne = ConsigneFactory(consigne="Une autre consigne")

        out = StringIO()
        call_command('changeconsigne', 1, verbosity=2, stdout=out)
        assert "Une autre consigne" in out.getvalue()
        jeu_settings.refresh_from_db()
        assert jeu_settings.consigne == consigne
