from django.conf import settings
from django.urls import path
from django.utils.decorators import method_decorator
from django.views.decorators.csrf import csrf_exempt

from rest_framework.exceptions import NotFound, ParseError
from rest_framework.parsers import JSONParser
from rest_framework.response import Response
from rest_framework.viewsets import ViewSet

from ..models import PushSubscription


class NotificationsAPIViewSet(ViewSet):
    parser_classes = [JSONParser]

    def info_view(self, request):
        return Response({'server_key': settings.VAPID_SERVER_KEY})

    @method_decorator(csrf_exempt)
    def subscribe_view(self, request):
        try:
            subscription_info = request.data['subscription']
            subscription, changed = PushSubscription.objects.update_or_create(
                subscription_info
            )
        except KeyError:
            raise ParseError("Le paramètre 'subscription' est requis.")
        except ValueError:
            raise ParseError("Le paramètre 'subscription' est incorrect.")
        return Response(
            {
                'detail': (
                    "L'abonnement a été enregistré."
                    if changed
                    else "L'abonnement est déjà à jour."
                )
            }
        )

    @method_decorator(csrf_exempt)
    def unsubscribe_view(self, request):
        try:
            PushSubscription.objects.get(
                endpoint=request.data['endpoint']
            ).delete()
        except KeyError:
            raise ParseError("Le paramètre 'endpoint' est requis.")
        except PushSubscription.DoesNotExist:
            raise NotFound("Aucun abonnement trouvé pour ce 'endpoint'.")
        return Response({'detail': "L'abonnement a été supprimé."})

    @classmethod
    def get_urlpatterns(cls):
        return [
            path(
                'subscribe/',
                cls.as_view({'post': 'subscribe_view'}),
                name='subscribe',
            ),
            path(
                'unsubscribe/',
                cls.as_view({'post': 'unsubscribe_view'}),
                name='unsubscribe',
            ),
            path('', cls.as_view({'get': 'info_view'}), name='info'),
        ]
