import logging
import time

from django.conf import settings

from pywebpush import WebPushException, webpush

logger = logging.getLogger('danse.notifications')


def send_notification(subscription, data, expiration=86400):
    """
    Envoie une notification via l'API Push à l'abonnement PushSubscription
    `subscription` avec comme contenu `data`, et comme durée d'expiration
    `expiration` (24h par défaut).
    """
    vapid_claims = {
        'sub': 'mailto:{}'.format(settings.VAPID_ADMIN_EMAIL),
        'exp': int(time.time()) + expiration,
    }
    try:
        webpush(
            subscription_info=subscription.info,
            data=data,
            vapid_private_key=settings.VAPID_PRIVATE_KEY,
            vapid_claims=vapid_claims,
        )
    except WebPushException as exc:
        if exc.response.status_code == 410:
            logger.info(
                "L'abonnement %r a expiré, il va être supprimé", subscription
            )
            subscription.delete()
        else:
            logger.error(
                "Impossible de notifier %r via l'API Push",
                subscription,
                exc_info=exc,
            )
        return False
    return True
