from django.conf import settings
from django.urls import include, path

from wagtail.admin import urls as wagtailadmin_urls
from wagtail.core import urls as wagtailcore_urls

from .api import api_router

urlpatterns = [
    path('admin/', include(wagtailadmin_urls)),
    path('api/v1/', api_router.urls),

    # sert les pages comme le frontend
    path('page/', include(wagtailcore_urls)),
]

if settings.DEBUG:
    from django.conf.urls.static import static
    from django.views import defaults as default_views

    urlpatterns += [
        path(
            '403/',
            default_views.permission_denied,
            kwargs={'exception': Exception('Permission Denied')},
        ),
        path(
            '404/',
            default_views.page_not_found,
            kwargs={'exception': Exception('Page not Found')},
        ),
        path('500/', default_views.server_error),
    ] + static(settings.MEDIA_URL, document_root=settings.MEDIA_ROOT)

    if 'debug_toolbar' in settings.INSTALLED_APPS:
        import debug_toolbar

        urlpatterns.insert(0, path('__debug__/', include(debug_toolbar.urls)))
