from django.contrib.auth.models import User, UserManager
from django.db import models


class StructureUserManager(UserManager):
    def get_for_user(self, user):
        """Retourne l'association avec une structure d'un compte."""
        try:
            return user.structureuser
        except AttributeError:
            raise self.model.DoesNotExist

    def create_for_user(self, user):
        """Crée une association avec une structure pour un compte."""
        try:
            return self.get_for_user(user)
        except self.model.DoesNotExist:
            structure_user = self.model(user_ptr_id=user.pk)
            structure_user.__dict__.update(user.__dict__)
            return structure_user

    def delete_for_user(self, user):
        """Supprime l'association avec une structure d'un compte."""
        return self.get_for_user(user).delete(keep_parents=True)


class StructureUser(User):
    """
    Associe une structure à un compte utilisateur.
    """

    structure = models.ForeignKey(
        'core.Structure', on_delete=models.SET_NULL, null=True
    )

    objects = StructureUserManager()

    @property
    def is_structure_user(self):
        return True
