import logging

from django.contrib.auth.tokens import default_token_generator
from django.db.models.signals import post_save
from django.template.loader import render_to_string
from django.urls import reverse
from django.utils.encoding import force_bytes
from django.utils.http import urlsafe_base64_encode

from wagtail.admin.mail import send_mail
from wagtail.core.models import Site

logger = logging.getLogger('danse.users')


def send_structure_welcome_mail(sender, instance, created, **kwargs):
    if not created:
        return

    context = {
        'user': instance,
        'root_url': Site.objects.get(is_default_site=True).root_url,
    }

    if not instance.password:
        # génère un token pour initialiser son mot de passe
        uid = urlsafe_base64_encode(force_bytes(instance.pk))
        token = default_token_generator.make_token(instance)

        context['password_reset_url'] = reverse(
            'wagtailadmin_password_reset_confirm',
            kwargs={'uidb64': uid, 'token': token},
        )

    email_subject = render_to_string(
        'users/mail/structure_welcome_subject.txt'
    ).strip()
    email_content = render_to_string(
        'users/mail/structure_welcome.txt', context
    ).strip()

    try:
        send_mail(email_subject, email_content, [instance.email])
    except Exception:  # pragma: no cover
        logger.exception(
            "Impossible d'envoyer le courriel de bienvenue à {}".format(
                instance.email
            )
        )


def register_signal_handlers():
    from .models import StructureUser

    post_save.connect(send_structure_welcome_mail, sender=StructureUser)
