from django.contrib.auth.models import Group, Permission, User
from django.utils.text import slugify

import factory
from factory.django import DjangoModelFactory
from factory.faker import Faker

from ..models import StructureUser


class UserFactory(DjangoModelFactory):
    class Meta:
        model = User

    first_name = Faker('first_name')
    last_name = Faker('last_name')
    email = Faker('email')

    @factory.lazy_attribute
    def username(self):
        return slugify(
            '{} {}'.format(self.first_name, self.last_name),
            allow_unicode=False,
        )


class StructureUserFactory(UserFactory):
    class Meta:
        model = StructureUser

    first_name = ''
    last_name = Faker('company')


class GroupFactory(DjangoModelFactory):
    class Meta:
        model = Group
        django_get_or_create = ('name',)

    name = factory.Sequence(lambda x: 'Groupe #{0}'.format(x))

    @factory.post_generation
    def permissions(self, create, extracted, codenames=None, **kwargs):
        if not create:
            return
        if codenames:
            for perm in Permission.objects.filter(codename__in=codenames):
                self.permissions.add(perm)
        if extracted:
            for perm in extracted:
                self.permissions.add(perm)
