from django.db.models import Q

from wagtail.search import index

from rest_framework.filters import BaseFilterBackend


class SearchFilter(BaseFilterBackend):
    """
    Filtre de recherche, sans passer par `wagtail.search`.

    Ce filtre permet notamment de contourner le problème des recherches
    partielles (avec `partial_match=True`) qui ne sont pas toujours
    fonctionnelles en fonction de la base de données.
    """

    def filter_queryset(self, request, queryset, view):
        """
        Filtre les objets de la requête avec ceux contenant un terme de
        recherche spécifié par `search`. Seuls les champs du modèle définis
        dans son attribut `search_fields` sont filtrés.
        """
        search_query = request.GET.get('search', None)

        if search_query:
            conditions = Q()

            for field in view.model.search_fields:
                if isinstance(field, index.SearchField):
                    conditions |= Q(
                        **{'%s__icontains' % field.field_name: search_query}
                    )

            queryset = queryset.filter(conditions)

        return queryset
