from wagtail.api.v2.utils import BadRequestError

from django_filters.rest_framework import DjangoFilterBackend


class DjangoFilterViewSetMixin:
    def check_query_parameters(self, queryset):
        """
        Vérifie que les arguments de la requête sont connus ou font partis
        des champs autorisés à être filtrés via django-filter.
        """
        filterset = DjangoFilterBackend().get_filterset(
            self.request, queryset, self
        )
        allowed_fields = set(
            [] if filterset is None else filterset.filters.keys()
        )
        allowed_parameters = allowed_fields.union(self.known_query_parameters)
        unknown_parameters = set(self.request.GET.keys()) - allowed_parameters
        if unknown_parameters:
            raise BadRequestError(
                "Query parameter is not an operation or a recognised field: "
                "{}".format(', '.join(sorted(unknown_parameters)))
            )
