from django.utils.functional import keep_lazy_text
from django.utils.html import MLStripper


class HTMLFilter(MLStripper):
    NEW_LINE_TAGS = {'p', 'div'}

    def handle_starttag(self, tag, attrs):
        if tag in self.NEW_LINE_TAGS:
            self.fed.append('\n')
        if tag == 'li':
            self.fed.append('\n * ')

    def handle_startendtag(self, tag, attrs):
        if tag == 'br':
            self.fed.append('\n')

    def get_data(self):
        return ''.join(self.fed).strip('\n')

    @classmethod
    def process(cls, value):
        s = cls()
        s.feed(value)
        s.close()
        return s.get_data()


@keep_lazy_text
def html_to_text(value):
    """
    Convertis du contenu HTML en texte en gardant autant que possible sa
    mise en forme (retours à la ligne, listes...).

    Basé sur `django.utils.html.strip_tags`.
    """
    value = str(value)
    while '<' in value and '>' in value:
        new_value = HTMLFilter.process(value)
        if value.count('<') == new_value.count('<'):
            break
        value = new_value
    return value
