import pytest

from ..api.serializers import StdImageField


class MockStdImageField:
    def __init__(self, variations={}):
        self.variations = variations


class MockFile:
    def __init__(self, name='', url='', field=None):
        self.name = name
        self.url = url
        self.field = field


class MockStdImageFieldFile(MockFile):
    def __init__(self, **kwargs):
        super().__init__(**kwargs)

        if self.field and hasattr(self.field, 'variations'):
            for name, value in self.field.variations.items():
                if value:
                    setattr(self, name, value)


class TestStdImageField:
    def test_init_use_url(self):
        field = StdImageField()
        assert field.use_url is True

        with pytest.warns(UserWarning):
            field = StdImageField(use_url=False)
        assert field.use_url is True

    def test_no_variations(self):
        field = StdImageField()
        obj = MockStdImageFieldFile(
            name='image.png', url='/image.png', field=MockStdImageField()
        )
        value = field.to_representation(obj)
        assert value == {'url': '/image.png', 'variations': {}}

    def test_variations_url(self):
        field = StdImageField()
        obj = MockStdImageFieldFile(
            name='image.png',
            url='/image.png',
            field=MockStdImageField(
                {
                    'thumbnail': MockFile(name='thumb.png', url='/thumb.png'),
                    'medium': MockFile(name='medium.png', url='/medium.png'),
                    'unknown': None,
                }
            ),
        )
        value = field.to_representation(obj)
        assert value == {
            'url': '/image.png',
            'variations': {
                'thumbnail': '/thumb.png',
                'medium': '/medium.png',
                'unknown': None,
            },
        }
