from django.utils.functional import lazystr

import pytest

from ..html import html_to_text


@pytest.mark.parametrize(
    ('value', 'output'),
    [
        ('Some sample text.', 'Some sample text.'),
        ('<p>Some <b>sample</b> text</p>', 'Some sample text'),
        ('<p>Some<br />sample</p><p>text</p>', 'Some\nsample\ntext'),
        (
            'List:<ul><li>item 1</li><li>item 2</li></ul>',
            'List:\n * item 1\n * item 2',
        ),
        ('<script>Some <p>script</p></script>', 'Some \nscript'),
        ('<p>Some <<img /> tag</p>', 'Some < tag'),
        ('&gotcha&#;<>', '&gotcha&#;<>'),
        ('X<<<<br>br>br>br>X', 'XX'),
    ],
)
def test_html_to_text(value, output):
    assert html_to_text(value) == output
    assert html_to_text(lazystr(value)) == output
