import pytest
from ics import Calendar, Event

from ..http import ICalResponse


class TestICalResponse:
    def test_invalid(self):
        with pytest.raises(ValueError):
            ICalResponse()

    def test_response(self):
        events = [
            Event(name="Event 1", begin="2020-01-01 00:00:00"),
            Event(name="Event 2", begin="2020-01-02 00:00:00"),
        ]
        response = ICalResponse(events=events)
        assert response.calendar.events == set(events)
        assert response['Content-Type'] == 'text/calendar'
        assert (
            response['Content-Disposition']
            == 'attachment; filename="calendar.ics"'
        )
        content = list(response)
        assert b"PRODID:Danse !\r\n" in content
        assert b"SUMMARY:Event 1\r\n" in content
        assert b"SUMMARY:Event 2\r\n" in content

    def test_filename(self):
        response = ICalResponse(calendar=Calendar(), filename='event.ics')
        assert (
            response['Content-Disposition']
            == 'attachment; filename="event.ics"'
        )

    def test_with_calendar_and_events(self):
        calendar = Calendar(
            creator="Pouet",
            events=[Event(name="Event 1", begin="2020-01-01 00:00:00")],
        )
        response = ICalResponse(
            calendar=calendar,
            events=[Event(name="Event 2", begin="2020-01-02 00:00:00")],
        )
        content = list(response)
        assert b"PRODID:Pouet\r\n" in content
        assert b"SUMMARY:Event 1\r\n" in content
        assert b"SUMMARY:Event 2\r\n" in content
