#!/bin/bash

set -eu

if [[ $# -ne 2 ]]; then
  echo "Usage : $(basename "$0") INPUT_IMAGE OUTPUT_DIR"
  exit 1
fi

INPUT="$1"
OUTPUT_DIR="$2"
mkdir -p "${OUTPUT_DIR}"

# fichiers temporaires
OUTPUT="map.vrt"
rm -f "${OUTPUT}" "_${OUTPUT}"

# systèmes de coordonnées
MAP_SRS='EPSG:3857'
DATA_SRS='EPSG:4326'

# taille de l'image
SIZE=('15000' '10000')

# ulx uly lrx lry
EXTENT=('-0.933838' '48.320697' '6.906110' '51.673907')

gdal_translate -ot Byte -of 'VRT' -a_srs "${DATA_SRS}" \
  -gcp 0 0 "${EXTENT[0]}" "${EXTENT[3]}" \
  -gcp "${SIZE[0]}" 0 "${EXTENT[2]}" "${EXTENT[3]}" \
  -gcp "${SIZE[0]}" "${SIZE[1]}" "${EXTENT[2]}" "${EXTENT[1]}" \
  -gcp 0 "${SIZE[1]}" "${EXTENT[0]}" "${EXTENT[1]}" \
  "${INPUT}" "_${OUTPUT}"

gdalwarp -t_srs "${MAP_SRS}" "_${OUTPUT}" "${OUTPUT}"

# nécessite gdal-bin >= 3.1
gdal2tiles.py --resampling=lanczos --s_srs="${MAP_SRS}" --xyz \
  --tilesize=256 --webviewer=openlayers \
  "${OUTPUT}" "${OUTPUT_DIR}"

rm -f "${OUTPUT}" "_${OUTPUT}"
