function urlBase64ToUint8Array(base64String) {
  const padding = '='.repeat((4 - (base64String.length % 4)) % 4);
  const base64 = (base64String + padding).replace(/-/g, '+').replace(/_/g, '/');

  const rawData = window.atob(base64);
  const outputArray = new Uint8Array(rawData.length);

  for (let i = 0; i < rawData.length; ++i) {
    outputArray[i] = rawData.charCodeAt(i);
  }
  return outputArray;
}

/**
 * Abonne le client au service Push du serveur ayant la clé donnée.
 * @param {String} serverKey
 * @returns {PushSubscription}
 */
export async function subscribeToPush(serverKey) {
  const registration = await navigator.serviceWorker.ready;
  const subscription = await registration.pushManager.subscribe({
    userVisibleOnly: true,
    applicationServerKey: urlBase64ToUint8Array(serverKey),
  });
  return subscription;
}

/**
 * Désabonne le client du service Push actuel.
 * @param {String} serverKey
 * @returns {(String|null)}
 */
export async function unsubscribeUserFromPush() {
  const registration = await navigator.serviceWorker.ready;
  const subscription = await registration.pushManager?.getSubscription();
  if (subscription && (await subscription?.unsubscribe()) === true) {
    return subscription?.endpoint;
  }
  return null;
}

/**
 * Détermine si le client est abonné au service Push.
 * @returns {Promise<Boolean>}
 */
export async function isSubscribedToPush() {
  try {
    const registration = await navigator.serviceWorker.getRegistration();
    return (await registration?.pushManager?.getSubscription()) != null;
  } catch (e) {
    return Promise.resolve(false);
  }
}
