import path from 'path';

import { version as VERSION } from '../package.json';

const defaults = {
  offlineAssets: ['/favicon.ico'],
  assetsURLPattern: '^/_nuxt/',
  notificationClickURL: '/',
};

export default function serviceWoker(moduleOptions) {
  if (this.options.dev) {
    return;
  }

  this.addPlugin({
    src: path.resolve(__dirname, 'templates/worker.js'),
    mode: 'client',
    fileName: 'worker.js',
    options: {
      ...this.options,
    },
  });

  this.nuxt.hook('build:before', () => {
    const options = { ...defaults, ...moduleOptions };
    const manifest = getManifest(this.nuxt.options);

    this.addTemplate({
      src: path.resolve(__dirname, 'templates/sw.js'),
      fileName: path.resolve(
        this.options.srcDir,
        this.options.dir.static || 'static',
        'sw.js'
      ),
      options: {
        ...this.options,
        ...options,
        version: VERSION,
        notificationIcon: getIconSrc(manifest, 512),
        notificationBadge: getIconSrc(manifest, 120),
      },
    });
  });
}

function getManifest(options) {
  const filename = path.basename(options.pwa._manifestMeta.href);
  return require(`${options.buildDir}/dist/client/${filename}`);
}

function getIconSrc(manifest, size) {
  for (let i = 0; i < manifest.icons.length; i++) {
    if (manifest.icons[i].sizes === `${size}x${size}`) {
      return manifest.icons[i].src;
    }
  }

  throw new Error(`Unable to find icon with size ${size}`);
}
