import jsonImporter from 'node-sass-json-importer';

/* eslint-disable dot-notation */
import COLORS from './common/colors.json';
import METADATA from './common/metadata.json';
import { version as VERSION } from './package.json';

const isDev = process.env.NODE_ENV !== 'production';

export default {
  // Disable server-side rendering
  ssr: false,
  target: 'static',

  // Disable telemetry data collecting
  telemetry: false,

  // Global page headers
  head: {
    title: METADATA['name'],
    link: [{ rel: 'icon', type: 'image/x-icon', href: '/favicon.ico' }],
  },

  // Loading progress-bar and indicator
  loading: {
    color: COLORS['orange'],
    height: '4px',
  },
  loadingIndicator: {
    color: COLORS['blue'],
    background: COLORS['white-ter'],
  },

  // Messages translation
  messages: {
    loading: 'Chargement…',
    error_404: 'La page demandée est introuvable.',
  },

  // Default transitions
  pageTransition: {
    name: 'slide-in',
    mode: '',
  },

  // Global CSS
  css: ['~/assets/scss/main.scss'],

  // Auto import components
  components: true,

  // Public environment variables
  publicRuntimeConfig: {
    clientVersion: VERSION,
    matomoHost: process.env.MATOMO_HOST,
    matomoSiteId: process.env.MATOMO_SITE_ID,
  },

  // Plugins to run before rendering page
  plugins: [
    '~/plugins/buefy.js',
    '~/plugins/date-fns.js',
    '~/plugins/dompurify.js',
    '~/plugins/filters.js',
    '~/plugins/scroll.js',
    { src: '~/plugins/matomo.js', mode: 'client' },
    { src: '~/plugins/vuex-persistedstate.js', mode: 'client' },
    // Local plugins
    '~/plugins/danse-pwa.js',
  ],

  // Modules
  modules: [
    [
      '~/modules/service-worker.js',
      {
        offlineAssets: ['/favicon.ico', '/icon.png'],
        assetsURLPattern: '^/(fonts|img|tiles|_nuxt)/',
        notificationClickURL: '/jouer/',
      },
    ],
    // https://http.nuxtjs.org/
    '@nuxt/http',
    // https://pwa.nuxtjs.org/
    '@nuxtjs/pwa',
    // https://github.com/nuxt-community/proxy-module
    ...(isDev ? ['@nuxtjs/proxy'] : []),
  ],

  // Modules for development and build
  buildModules: [
    // https://github.com/nuxt-community/eslint-module
    '@nuxtjs/eslint-module',
    // https://github.com/nuxt-community/stylelint-module
    '@nuxtjs/stylelint-module',
  ],

  // Build configuration
  build: {
    loaders: {
      css: {
        importLoaders: 1,
      },
      scss: {
        sassOptions: {
          importer: jsonImporter(),
        },
      },
    },
  },

  //
  // Modules configuration
  //

  http: {
    browserBaseURL: '/',
    proxy: isDev,
    clientTimeout: 6000,
  },

  pwa: {
    manifest: {
      name: METADATA['name'],
      short_name: METADATA['name'],
      description: METADATA['description'],
      background_color: COLORS['white-ter'],
      theme_color: COLORS['blue'],
      lang: 'fr',
    },
    meta: {
      author: false,
    },
    workbox: false,
  },

  proxy: ['http://127.0.0.1:8000/api'],
};
