import Vue from 'vue';
import dateFormat from 'date-fns/format';
import locale from 'date-fns/locale/fr';

const OPTIONS = { locale };
const FORMATS = {
  DEBUT_SHORT: (value) => {
    const format = `eee d MMM '⋅' H'h'`;
    return value.getMinutes() === 0 ? format : `${format}mm`;
  },
  DEBUT_LONG: (value) => {
    const format = `eeee d MMMM yyyy '⋅' H'h'`;
    return value.getMinutes() === 0 ? format : `${format}mm`;
  },
};

const getFormat = (formatStr, value) => {
  const format = FORMATS[formatStr] || formatStr;
  return typeof format === 'function' ? format(value) : format;
};

export function format(value, formatStr) {
  if (typeof value === 'string') {
    value = new Date(value);
  }

  // voir : https://date-fns.org/docs/format#arguments
  return dateFormat(value, getFormat(formatStr, value), OPTIONS);
}

export function toISODateString(value) {
  return format(value, 'yyyy-MM-dd');
}

Vue.filter('date', format);
