import Vue from 'vue';

/**
 * Définis une directive `v-scroll` permettant d'exécuter la fonction
 * donnée comme valeur à chaque évènement `scroll` sur l'élément, ou
 * sur la fenêtre si le *modifier* `window` est présent.
 */
Vue.directive('scroll', {
  inserted(el, binding) {
    const callback = binding.value;
    const target = binding.modifiers.window ? window : el;

    target.addEventListener('scroll', callback, { passive: true });

    el._scroll = { callback, target };
  },
  unbind(el) {
    if (el._scroll) {
      return;
    }

    const { callback, target } = el._scroll;
    target.removeEventListener('scroll', callback);

    delete el._scroll;
  },
});
