import api from '~/common/api';

// Le nombre maximum de rejet avant de ne plus proposer de jouer.
const MAX_USER_REJECT = 3;

export const state = () => ({
  consigne: null,
  consigneId: null,
  instructions: null,
  isActive: false,
  lastUpdate: null,
  // preferences
  user: {
    isActive: true,
    lastConsigneId: null,
    rejectCounter: 0,
  },
});

export const getters = {
  /**
   * Détermine s'il faut proposer à la personne de jouer.
   * @returns {Boolean}
   */
  userCanPlay(state) {
    return (
      state.isActive &&
      state.user.isActive &&
      state.user.lastConsigneId !== state.consigneId
    );
  },
};

export const actions = {
  async fetch({ commit }) {
    try {
      commit('SET', await this.$http.$get(api.Jouer.CONSIGNE));
    } catch (err) {
      commit('CLEAR');
    }
  },
  play({ commit }) {
    commit('UPDATE_USER_STATE');
  },
  reject({ commit }) {
    commit('UPDATE_USER_STATE', true);
  },
};

export const mutations = {
  CLEAR(state) {
    state.isActive = false;
    state.lastUpdate = Date.now();
  },
  /* eslint-disable camelcase */
  SET(state, { consigne, consigne_id, instructions }) {
    if (!state.isActive || consigne_id !== state.consigneId) {
      state.consigne = consigne;
      state.consigneId = consigne_id;
      state.instructions = instructions;
      state.lastUpdate = Date.now();
      state.isActive = true;
    }
  },
  /* eslint-enable camelcase */
  UPDATE_USER_STATE(state, hasRejected = false) {
    state.user.lastConsigneId = state.consigneId;

    if (hasRejected) {
      state.user.rejectCounter += 1;

      if (state.user.rejectCounter >= MAX_USER_REJECT) {
        state.user.isActive = false;
      }
    }
  },
  SET_USER_ISACTIVE(state, isActive) {
    state.user.isActive = isActive;
  },
};
