import test from 'ava';

import {
  capfirst,
  currency,
  duration,
  geocoords,
  hostname,
  pluralize,
  postcode,
} from '~/plugins/filters';

// Utils

function valueIs(t, fn, value, expected) {
  t.is(fn.apply(null, Array.isArray(value) ? value : [value]), expected);
}

valueIs.title = (providedTitle, fn, value, expected) =>
  `${fn.name}(${JSON.stringify(value)}) = ${JSON.stringify(expected)}`.trim();

// Tests

test(valueIs, capfirst, 'un titre', 'Un titre');

test(valueIs, currency, '21', '21 €');
test(valueIs, currency, '21.00', '21 €');
test(valueIs, currency, '21.50', '21,5 €');
test(valueIs, currency, 21.0, '21 €');
test(valueIs, currency, 21.5, '21,5 €');
test(valueIs, currency, null, '');
test(valueIs, currency, ['0', 'Gratuit'], 'Gratuit');

test(valueIs, duration, '1', '1s');
test(valueIs, duration, '60', '1min');
test(valueIs, duration, '90', '1min30s');
test(valueIs, duration, 3600, '1h');
test(valueIs, duration, 3600 + 1, '1h01s');
test(valueIs, duration, 3600 + 60, '1h01');
test(valueIs, duration, 3600 + 30 * 60, '1h30');
test(valueIs, duration, ['0', '-'], '-');

test(valueIs, geocoords, { lat: 1.0, lon: 2.1 }, 'geo:1,2.1');
test(valueIs, geocoords, { lat: 1.0 }, '');
test(valueIs, geocoords, ['', '-'], '-');

const url = 'http://www.example.org/path';

test(valueIs, hostname, url, 'example.org');
test(valueIs, hostname, [url, false], 'www.example.org');
test(valueIs, hostname, 'invalid.org/path', 'invalid.org');

test(valueIs, pluralize, ['word', 0], 'words');
test(valueIs, pluralize, ['word', 1], 'word');
test(valueIs, pluralize, ['word', 2], 'words');
test(valueIs, pluralize, ['word', 1, 'more'], 'word');
test(valueIs, pluralize, ['word', 2, 'more'], 'more');

test(valueIs, postcode, '59000', '59 000');
test(valueIs, postcode, ['59000', true], '59');
